@@ -6,6 +6,8 @@
 
 from __future__ import print_function
 
+import time
+
 import rtmidi
 from rtmidi.midiconstants import (ALL_SOUND_OFF, CONTROL_CHANGE,
                                   RESET_ALL_CONTROLLERS)
@@ -16,9 +18,11 @@ print(__doc__)
 
 for portnum, portname in enumerate(midiout.get_ports()):
     print("Port:", portname)
-    midiout.open_port(portnum)
-    for channel in range(16):
-        midiout.send_message([CONTROL_CHANGE, ALL_SOUND_OFF, 0])
-        midiout.send_message([CONTROL_CHANGE, RESET_ALL_CONTROLLERS, 0])
 
-    midiout.close_port()
+    with midiout.open_port(portnum):
+        for channel in range(16):
+            midiout.send_message([CONTROL_CHANGE, ALL_SOUND_OFF, 0])
+            midiout.send_message([CONTROL_CHANGE, RESET_ALL_CONTROLLERS, 0])
+            time.sleep(0.05)
+
+        time.sleep(0.1)
